CiteAb | The Antibody Search Engine
Description: The world's largest antibody search engine, with results ranked by citations.

New! Nominations are now open for the CiteAb Antibody Awards 2014!

#

## The Antibody Search Engine

Search

# The world's largest antibody search engine, with results ranked by citations.

## Searching a database of 2,086,303 antibodies, with 537,791 citations from 119 suppliers.

# Browse antibodies by

Supplier Host Application Reactivity

## The CiteAb Antibody Awards 2014

Nominations have opened to the very first CiteAb Antibody Awards.

Posted by Matt on 3 December. Read More →

## Meeting Avacta, and introducing affimers

Learn about Affimers - engineered proteins that mimic the specificity and binding affinities of antibodies

Posted by Matt on 27 November. Read More →

## Launching our new Institution Dataset

Shedding light on the most active research institutions.

Posted by Matt on 20 November. Read More →

# Featured antibodies

## CD4, Mouse Anti-Human, (APC)

This APC conjugated antibody from Life Technologies has been shown to be effective for FACS of human cells.

## Anti-TGF-beta 1, 2, 3 Monoclonal Antibody (Clone 1D11)

Antibodies for ELISA? Try this anti-TGFbeta one from R&D Systems.

## FITC anti-mouse CD8a Antibody [53-6.7]; Monoclonal

CiteAb lists conjugated antibodies such as this FITC conjugated anti-CD8a antibody from Biolegend.

# Custom antibodies

If you can't find the antibody you're looking for in our database, why not consider a custom antibody from a custom antibody supplier - manufactured to your exact requirements.

Browse custom antibody suppliers

# Join our mailing list

Find out when we list new antibodies and keep up with the latest exciting developments at CiteAb.